@@ -1,6 +1,8 @@
+import os
 import json
 import typing
 from pathlib import Path
+import pymongo
 
 import grpc
 
@@ -26,8 +28,17 @@ class LogReplayNodeClient(object):
         if platform.system() ==  'Windows' :
             self._shareMemReplayData = SharedMemZoneSender(None, name='ZoneSenderReplay')
 
+        # mongodb配置
+        self._mongo_client = pymongo.MongoClient(
+            "mongodb://{0}:{1}/".format(
+                ZoneSenderData.MONGO_WIRED_TIGER_HOST,
+                ZoneSenderData.MONGO_WIRED_TIGER_PORT))
+        self._MONGO_DB_NAME = ZoneSenderData.MONGO_DB_NAME
+        self._MONGO_COLLECT_NAME_LOG_REPLAY = ZoneSenderData.MONGO_COLLECT_NAME_LOG_REPLAY
+        self._mongo_collect = self._mongo_client[self._MONGO_DB_NAME][self._MONGO_COLLECT_NAME_LOG_REPLAY]
+
     def AddLinDecodeRole(
-        self, 
+        self,
         channels: typing.List[int],
         ldfs: typing.List[str],
         **kwargs) -> int:
@@ -97,7 +108,7 @@ class LogReplayNodeClient(object):
         except Exception as e_:
             print('LogReplayNodeClient.AddCanDecodeRole Exception reason {0}'.format(e_))
             return 1000
-    
+
     def AddSomeIpDecodeRole(self,someip_arxml_path:str) :
         '''
         添加一个 SomeIp 数据的解析规则
@@ -136,10 +147,10 @@ class LogReplayNodeClient(object):
             return 1000
 
     def ReplayNextN(
-        self, 
-        blf_file_path: str, 
-        count: int, 
-        result_l_obj: typing.List[BlfIoObjs.BlfIoStruct], 
+        self,
+        blf_file_path: str,
+        count: int,
+        result_l_obj: typing.List[BlfIoObjs.BlfIoStruct],
         reslut_l_time_stamp: typing.List[int]) -> int:
         '''
         解包 N 个数据
@@ -161,7 +172,7 @@ class LogReplayNodeClient(object):
             start_index_ = int(res_.start_index)    # 起始 index
             stop_index_ = int(res_.stop_index)    # 结束 index
             is_stop_ = bool(res_.is_stop)    # 是否读完了
-            
+
             # 写数据 >>>>>>>>
             result_l_obj.clear()
             reslut_l_time_stamp.clear()
@@ -178,6 +189,117 @@ class LogReplayNodeClient(object):
             print('LogReplayNodeClient.DecodeNextN Exception reason {0}'.format(e_))
             return 1000
 
+    def ParseToDb(
+            self,
+            blf_file_path: str,
+            count: int,
+            real_count: typing.List[int],
+            # result_l_obj: typing.List[BlfIoObjs.BlfIoStruct],
+            # reslut_l_time_stamp: typing.List[int]
+    ) -> int:
+        '''
+        解包 N 个数据
+        :param blf_file_path:str 要读的 Blf 文件名
+        :param count:int 要解析下面的多少个数据 不能超过 131000
+        :param result_l:list[BlfIoObjs.BlfIoStruct] 解析后的数据 里面会放 BlfIoObjs.CanISignalIPduPy | BlfIoObjs.LinFramePy
+        :return:int
+            - 0:成功
+            - 1:读结束
+        '''
+        try:
+            res_ = self._logReplayStub.ParseToDb(LogReplayNode_pb2.decode_n(
+                blf_file_path=blf_file_path,
+                count=count,
+            )
+            )
+            result_ = int(res_.result.result)  # 结果
+            reason_ = str(res_.result.reason)  # 原因
+            start_index_ = int(res_.start_index)  # 起始 index
+            stop_index_ = int(res_.stop_index)  # 结束 index
+            is_stop_ = bool(res_.is_stop)  # 是否读完了
+
+            real_count.append(stop_index_ - start_index_)
+
+            return res_.result.result
+
+        except Exception as e_:
+            # import traceback
+            # _e1 = str(traceback.format_exc())
+            print('LogReplayNodeClient.ParseToDb Exception reason {0}'.format(e_))
+            return 1000
+
+    def ClearDb(self) -> int:
+        '''
+        清除数据库mongodb
+        :return:int
+            - 0: 清除成功
+            - 1000: raise
+        '''
+        try:
+            self._mongo_collect.drop()
+            return 0
+        except Exception as e_:
+            # import traceback
+            # e1 = str(traceback.format_exc())
+            # print(e1)
+            print('LogReplayNodeClient.ClearDb Exception reason {0}'.format(e_))
+            return 1000
+
+    def DbDump(self, file_path: str) -> int:
+        '''
+        打开回放的文件
+        :param blf_file_path:str 要打开的文件路径
+        :return:int
+            - 0:成功
+            - other:失败
+        '''
+        try:
+            if file_path[-3:] != ".gz":
+                raise Exception("请输入正确的文件格式*.gz")
+            # 如果是相对路径转换为绝对路径
+            if not os.path.isabs(file_path):
+                file_path = os.path.abspath(file_path)
+
+            print(file_path)
+            res_ = self._logReplayStub.DbDump(
+                LogReplayNode_pb2.Common__pb2.file_path(
+                    path=file_path,
+                )
+            )
+            print(res_.reason)
+            return res_.result
+        except Exception as e_:
+            print('LogReplayNodeClient.dst_path Exception reason {0}'.format(e_))
+            return 1000
+
+
+    def DbRestore(self, archive: str, ns_to: str) -> int:
+        '''
+        打开回放的文件
+        :param blf_file_path:str 要打开的文件路径
+        :return:int
+            - 0:成功
+            - other:失败
+        '''
+        try:
+            # 如果是相对路径转换为绝对路径
+            if not os.path.isabs(archive):
+                archive = os.path.abspath(archive)
+            if not os.path.isfile(archive):
+                raise Exception("该文件不存在：{0}".format(archive))
+
+            res_ = self._logReplayStub.DbRestore(
+                LogReplayNode_pb2.restore_param(
+                    archive=archive,
+                    ns_to=ns_to
+                )
+            )
+            print(res_.reason)
+            return res_.result
+        except Exception as e_:
+            print('LogReplayNodeClient.DbRestore Exception reason {0}'.format(e_))
+            return 1000
+
     def OpenReplayFile(self, blf_file_path: str) -> int:
         '''
         打开回放的文件
