@@ -25,4 +25,4 @@ class CanFrame(ZoneSenderObject):
 
     def __str__(self) -> str:
         # return super().__str__()
-        return 'name: {0} data: {2}'.format(self.name, self.data)
\ No newline at end of file
+        return 'name: {0}, id: 0x {:04X} data: {2}'.format(self.name, self.id, self.data)
\ No newline at end of file
