@@ -23,6 +23,6 @@ class CanISignalIPdu(ZoneSenderObject):
 
     def __str__(self) -> str:
         # return super().__str__()
-        return 'name: {0} data: {1}'.format(self.name, self.data)
+        return 'name: {0} data: {1} context: {2}'.format(self.name, self.data, self.context)
     
     
\ No newline at end of file
