@@ -27,4 +27,4 @@ class LinFrame(ZoneSenderObject):
 
     def __str__(self) -> str:
         # return super().__str__()
-        return 'name: {0} data: {2}'.format(self.name, self.data)
\ No newline at end of file
+        return 'name: {0} data: {1}'.format(self.name, self.context_raw)
\ No newline at end of file
