@@ -1,6 +1,7 @@
 from typing import Union
 import json
 import typing
+import os
 
 import grpc
 
@@ -70,7 +71,7 @@ class SomeipNodeClient(object):
             print(e_)
             return 1000
     
-    def GetLoggingStatus(self) -> Union[tuple,int]:
+    def GetLoggingStatus(self, info: dict) -> 'int':
         ''' 获取记录数据状态
         :return: tuple\n
             - tuple: 成功 tuple[0] 1为有任务，0是没有任务；tuple[1] 为当前记录文件名\n
@@ -80,13 +81,19 @@ class SomeipNodeClient(object):
             res_ = self._someipNodeStub.GetLogStatus(
                 SomeIpNode_pb2.Common__pb2.empty()
             )
-            return (res_.result,res_.reason)
+            # return (res_.result,res_.reason)
+            info.update({
+                'file_path': res_.reason
+            })
+            return res_.result
         except Exception as e_ :
             print(e_)
             return 1000
 
     def StartSomeIpStack(self, ip_addr: 'str', iface: 'str') -> 'int':
         ''' 启动 SomeIp 协议栈
+        :param ip_addr: str 本机IP地址
+        :param file_name: str 本机网卡名字
 
         :return: int\n
             - 0: 成功\n
@@ -104,6 +111,34 @@ class SomeipNodeClient(object):
         except Exception as e_:
             print(e_)
             return 1000
+    
+    def StartSomeIpBypass(self) :
+        try:
+            ''' 启动 SomeIpBypass 协议栈
+
+            :return: int\n
+                - 0: 成功\n
+                - 1000: error\n
+            '''
+            res_ = self._someipNodeStub.StartSomeIpStackBypass(SomeIpNode_pb2.Common__pb2.empty())
+            return res_.result
+        except Exception as e_ :
+            print(e_)
+            return 1000
+    
+    def StopSomeIpByPass(self) :
+        try:
+            '''关闭 SomeIpBypass 协议栈
+
+            :return: int\n
+                - 0: 成功\n
+                - 1000: error\n
+            '''
+            res_ = self._someipNodeStub.StopSomeIpStackBypass(SomeIpNode_pb2.Common__pb2.empty())
+            return res_.result
+        except Exception as e_ :
+            print(e_)
+            return 1000
 
     def StopSomeIpStack(self) -> 'int':
         '''关闭 SomeIp 协议栈
@@ -119,7 +154,7 @@ class SomeipNodeClient(object):
                 SomeIpNode_pb2.Common__pb2.empty()
             )
             print('关闭SomeIp协议栈, result: {0}, reason:{1}'.format(res_.result, res_.reason))
-            return res_.reason
+            return res_.result
         except Exception as e_:
             print(e_)
             return 1000
@@ -140,7 +175,7 @@ class SomeipNodeClient(object):
                 )
             )
             print('加载 SomeIp Arxml 文件 result: {0}, reason: {1}'.format(res_.result, res_.reason))
-            return res_.reason
+            return res_.result
         except Exception as e_:
             print(e_)
             return 1000
@@ -346,7 +381,7 @@ class SomeipNodeClient(object):
     def GetAllOfferService(self, offer_services_out:list) -> int:
         '''
         获取当前 SomeipStack 所有的 Offer 的服务\n
-        注意，如果获取成功，offer_service 会清空\n
+        注意, 如果获取成功, offer_service 会清空\n
         :param offer_service:list 获取到的服务信息将传到该 list 中\n
         :return:int
             - 0:获取成功
@@ -374,5 +409,87 @@ class SomeipNodeClient(object):
             print('GetAllOfferService Except {0}'.format(e_))
             return 1000
 
+    def ConvertSomeipDbToPy(self, src_file:str, dst_file:str) -> int:
+        '''
+        将指定的 SomeipDB 文件转换成 .py 的代码提示辅助文件
+        :param src_file:str 输入的文件, 支持两种类型: CANxxx.arxml 和 CANxxx.json, 支持输入相对路径和绝对路径
+        :param dst_file:str 输出的文件, 将转换的文件写到哪里。注意 python 的 import 不支持 . 和 -
+        :return:int 返回结果 0 成功 其他失败
+        '''
+        try:
+            if (not os.path.isabs(src_file)):
+                src_file = os.path.abspath(src_file)
+            if (not os.path.isabs(dst_file)):
+                dst_file = os.path.abspath(dst_file)
+            res_ = self._someipNodeStub.ConvertSomeipDbToPy(
+                SomeIpNode_pb2.convert_input(
+                    src_file = src_file,
+                    dst_file = dst_file,
+                )
+            )
+            print('ConvertSomeipDbToPy result: {0}, reason: {1}'.format(res_.result, res_.reason))
+            return res_.result
+        except Exception as e_:
+            print('ConvertSomeipDbToPy Exception: ', e_)
+            return 1000
 
-    
\ No newline at end of file
+    def ConvertSomeipDbToJson(self, src_file:str, dst_file:str) -> int:
+        '''
+        将指定的 SomeipDB 文件转换成 .json 的方便看里面内容的文件
+        :param src_file:str 输入的文件, 支持类型: CANxxx.arxml
+        :param dst_file:str 输出的文件, 将转换的文件写到哪里, 建议使用 .json 后缀
+        :return:int 返回结果 0 成功 其他失败
+        '''
+        try:
+            if (not os.path.isabs(src_file)):
+                src_file = os.path.abspath(src_file)
+            if (not os.path.isabs(dst_file)):
+                dst_file = os.path.abspath(dst_file)
+            res_ = self._someipNodeStub.ConvertSomeipDbToJson(
+                SomeIpNode_pb2.convert_input(
+                    src_file = src_file,
+                    dst_file = dst_file,
+                )
+            )
+            print('ConvertSomeipDbToJson result: {0}, reason: {1}'.format(res_.result, res_.reason))
+            return res_.result
+        except Exception as e_:
+            print('ConvertSomeipDbToJsonClient Exception: ', e_)
+            return 1000
+    
+    def GetServiceStates(self, service_states: typing.List[SomeipServiceState]) -> int:
+        '''
+        获取当前正在运行的 SomeipService 状态
+        :param service_states:list[SomeipServiceState] 空 list, 如果本函数调用成功，就会填充这个 list
+        :return:int 调用结果
+        
+        详细的 SomeipServiceState 请看该数据结构的源码注释
+        关于服务状态的判定逻辑：
+            - 如果该服务作为 Providr, 一般服务启动后，只要网络没有问题，都是 True
+            - 如果该服务作为 Consumer, 判定逻辑如下
+                - 如果该服务有 EventGroupID，那么收到 Provider 的 SubscriberACK 的时候，
+                就判定为 True, 否则为 False
+                - 如果该服务没有 EventGroupID，如果发现了该服务的 Offer 且 TCP 建连成功就
+                判定为 True ，否则为 False，如果该服务是 UDP，那么只需要判定该有没有该服务的
+                Offer, 如果有 Offer，就判定成功。
+        '''
+        try:
+            res_ = self._someipNodeStub.GetServiceStates(
+                SomeIpNode_pb2.Common__pb2.empty()
+            )
+            if (not res_.result.result == 0):
+                # 如果返回结果失败
+                return res_.result.result
+            for service_state_ in res_.service_states:
+                service_states.append(SomeipServiceState(
+                    service_name=service_state_.service_name,
+                    service_id=service_state_.service_id,
+                    instance_id=service_state_.instance_id,
+                    service_state=service_state_.service_state,
+                    service_side=service_state_.service_side,
+                ))
+            print('[SomeipNodeClient.GetServiceStates] 成功，result: {0}, reason: {1}'.format(res_.result.result, res_.result.reason))
+            return res_.result.result
+        except Exception as e_:
+            print('[SomeipNodeClient.GetServiceStates] 失败，reason: {0}'.format(e_))
+            return 1000
\ No newline at end of file
