@@ -44,4 +44,10 @@ GRPC_OPTIONS = [
 MQTT_BROKER_IP = '127.0.0.1'
 MQTT_BROKER_PORT = 8083
 
-# MQTT 常量 <<<<<<<<<<<<<<<<<<<<<<<<<
\ No newline at end of file
+# MQTT 常量 <<<<<<<<<<<<<<<<<<<<<<<<<
+
+MONGO_WIRED_TIGER_HOST = "localhost"
+MONGO_WIRED_TIGER_PORT = 27017
+MONGO_DB_NAME = "zone_db"
+MONGO_COLLECT_NAME_LOG_REPLAY = "log_replay"
+
