@@ -812,7 +812,7 @@ class ZoneSenderStone(ZoneSenderFramework):
         self._threadPool.submit(self.OnDiagRequest_DoIP, diag_msg_)
 
     def _DealWithDoIPUdsMessageResponse(self, recv_d: dict):
-        print("_DealWithDoIPUdsMessageResponse", recv_d)
+        # print("_DealWithDoIPUdsMessageResponse", recv_d)
         diag_msg_ = DoIPDiagMessage(target_address=recv_d['target_address'], header_type=recv_d['header_type'], cmd=recv_d['d'])
         self._threadPool.submit(self.OnDiagResponse_DoIP, diag_msg_)
 
